@@ -10,10 +10,10 @@ require POSIX;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = '1.13_01'; # keep same as in Tty.pm
+$VERSION = 1.01; # keep same as in Tty.pm
 
 @ISA = qw(IO::Handle);
-eval { local $^W = 0; undef local $SIG{__DIE__}; require IO::Stty };
+eval { undef local $SIG{__DIE__}; local $^W = 0; require IO::Stty };
 push @ISA, "IO::Stty" if (not $@);  # if IO::Stty is installed
 
 sub new {
@@ -68,7 +68,7 @@ sub slave {
     return ${*$master}{'io_pty_slave'};
   }
 
-  my $tty = ${*$master}{'io_pty_ttyname'};
+  my $tty = $master->ttyname();
 
   my $slave = new IO::Tty;
 
@@ -84,7 +84,7 @@ sub make_slave_controlling_terminal {
   my $self = shift;
   local(*DEVTTY);
 
-  # loose controlling terminal explicitly
+  # loose controlling terminal explicitely
   if (defined TIOCNOTTY) {
     if (open (\*DEVTTY, "/dev/tty")) {
       ioctl( \*DEVTTY, TIOCNOTTY, 0 );
@@ -115,18 +115,13 @@ sub make_slave_controlling_terminal {
   }
 
   # Acquire a controlling terminal if this doesn't happen automatically
-  if (not open(\*DEVTTY, "/dev/tty")) {
-    if (defined TIOCSCTTY) {
-      if (not defined ioctl( ${*$self}{'io_pty_slave'}, TIOCSCTTY, 0 )) {
-        warn "warning: TIOCSCTTY failed, slave might not be set as controlling terminal: $!" if $^W;
-      }
-    } elsif (defined TCSETCTTY) {
-      if (not defined ioctl( ${*$self}{'io_pty_slave'}, TCSETCTTY, 0 )) {
-        warn "warning: TCSETCTTY failed, slave might not be set as controlling terminal: $!" if $^W;
-      }
-    } else {
-      warn "warning: You have neither TIOCSCTTY nor TCSETCTTY on your system\n" if $^W;
-      return 0;
+  if (defined TIOCSCTTY) {
+    if (not defined ioctl( ${*$self}{'io_pty_slave'}, TIOCSCTTY, 0 )) {
+      warn "warning: TIOCSCTTY failed, slave might not be set as controlling terminal: $!" if $^W;
+    }
+  } elsif (defined TCSETCTTY) {
+    if (not defined ioctl( ${*$self}{'io_pty_slave'}, TCSETCTTY, 0 )) {
+      warn "warning: TCSETCTTY failed, slave might not be set as controlling terminal: $!" if $^W;
     }
   }
 
@@ -141,8 +136,6 @@ sub make_slave_controlling_terminal {
 }
 
 *clone_winsize_from = \&IO::Tty::clone_winsize_from;
-*get_winsize = \&IO::Tty::get_winsize;
-*set_winsize = \&IO::Tty::set_winsize;
 *set_raw = \&IO::Tty::set_raw;
 
 1;
@@ -155,7 +148,7 @@ IO::Pty - Pseudo TTY object class
 
 =head1 VERSION
 
-1.13_01
+1.00
 
 =head1 SYNOPSIS
 
@@ -256,17 +249,6 @@ silently returns OK.
 
 See the C<try> script for example code how to propagate SIGWINCH.
 
-=item get_winsize()
-
-Returns the terminal size, in a 4-element list.
-
- ($row, $col, $xpixel, $ypixel) = $tty->get_winsize()
-
-=item set_winsize($row, $col, $xpixel, $ypixel)
-
-Sets the terminal size. If not specified, C<$xpixel> and C<$ypixel> are set to
-0.  As with C<clone_winsize_from>, this must be called upon the I<slave>.
-
 =back
 
 
