@@ -1,5 +1,4 @@
 # Documentation at the __END__
-# -*-cperl-*-
 
 package IO::Tty;
 
@@ -13,11 +12,11 @@ require DynaLoader;
 
 use vars qw(@ISA $VERSION $XS_VERSION $CONFIG $DEBUG);
 
-$VERSION = '1.13_01';
-$XS_VERSION = "1.13_01";
+$VERSION = 1.01;
+$XS_VERSION = "1.01";
 @ISA = qw(IO::Handle);
 
-eval { local $^W = 0; undef local $SIG{__DIE__}; require IO::Stty };
+eval { undef local $SIG{__DIE__}; local $^W = 0; require IO::Stty };
 push @ISA, "IO::Stty" if (not $@);  # if IO::Stty is installed
 
 BOOT_XS: {
@@ -51,10 +50,10 @@ sub open {
 
 sub clone_winsize_from {
   my ($self, $fh) = @_;
+  my $winsize = "";
   croak "Given filehandle is not a tty in clone_winsize_from, called"
     if not POSIX::isatty($fh);  
   return 1 if not POSIX::isatty($self);  # ignored for master ptys
-  my $winsize = " "x1024; # preallocate memory
   ioctl($fh, &IO::Tty::Constant::TIOCGWINSZ, $winsize)
     and ioctl($self, &IO::Tty::Constant::TIOCSWINSZ, $winsize)
       and return 1;
@@ -62,25 +61,6 @@ sub clone_winsize_from {
   return undef;
 }
 
-# ioctl() doesn't tell us how long the structure is, so we'll have to trim it
-# after TIOCGWINSZ
-my $SIZEOF_WINSIZE = length IO::Tty::pack_winsize(0,0,0,0);
-
-sub get_winsize {
-  my $self = shift;
-  ioctl($self, IO::Tty::Constant::TIOCGWINSZ(), my $winsize)
-    or croak "Cannot TIOCGWINSZ - $!";
-  substr($winsize, $SIZEOF_WINSIZE) = "";
-  return IO::Tty::unpack_winsize($winsize);
-}
-
-sub set_winsize {
-  my $self = shift;
-  my $winsize = IO::Tty::pack_winsize(@_);
-  ioctl($self, IO::Tty::Constant::TIOCSWINSZ(), $winsize)
-    or croak "Cannot TIOCSWINSZ - $!";
-}
-
 sub set_raw($) {
   require POSIX;
   my $self = shift;
@@ -118,7 +98,7 @@ IO::Tty - Low-level allocate a pseudo-Tty, import constants.
 
 =head1 VERSION
 
-1.13_01
+1.00
 
 =head1 SYNOPSIS
 
@@ -133,14 +113,13 @@ You wouldn't want to use it directly except to import constants, use
 C<IO::Pty>.  For a list of importable constants, see
 L<IO::Tty::Constant>.
 
-Windows is now supported, but ONLY under the Cygwin
+Windows is now supported, not natively but under the Cygwin
 environment, see L<http://sources.redhat.com/cygwin/>.
 
 Please note that pty creation is very system-dependend.  From my
 experience, any modern POSIX system should be fine.  Find below a list
-of systems that C<IO::Tty> should work on.  A more detailed table
-(which is slowly getting out-of-date) is available from the project
-pages document manager at SourceForge
+of systems that C<IO::Tty> should work on.  A more detailed table is
+available from the project pages document manager at SourceForge
 L<http://sourceforge.net/projects/expectperl/>.
 
 If you have problems on your system and your system is listed in the
@@ -154,10 +133,8 @@ do a C<'perl Makefile.PL; make; make test; uname -a'> and send me
 that.  There are chances that it will work right out-of-the-box...
 
 If it's working on your system, please send me a short note with
-details (version number, distribution, etc. 'uname -a' and 'perl -V'
-is a good start; also, the output from "perl Makefile.PL" contains a
-lot of interesting info, so please include that as well) so I can get
-an overview.  Thanks!
+details (version number, distribution, etc. C<'uname -a'> is a good
+start) so I can get an overview.  Thanks!
 
 
 =head1 VERIFIED SYSTEMS, KNOWN ISSUES
@@ -171,8 +148,6 @@ test' passes) with comments about "features":
 
 Returns EIO instead of EOF when the slave is closed.  Benign.
 
-=item * AIX 5.x
-
 =item * FreeBSD 4.4
 
 EOF on the slave tty is not reported back to the master.
@@ -184,8 +159,6 @@ Tcl/Expect, see http://expect.nist.gov/FAQ.html
 
 EOF on the slave tty is not reported back to the master.
 
-=item * Darwin 7.9.0
-
 =item * HPUX 10.20 & 11.00
 
 EOF on the slave tty is not reported back to the master.
@@ -206,7 +179,7 @@ Has the "feature" of returning EOF just once?!
 
 EOF on the slave tty is not reported back to the master.
 
-=item * Windows NT/2k/XP (under Cygwin)
+=item * Windows NT/2k (under Cygwin)
 
 When you send (print) a too long line (>160 chars) to a non-raw pty,
 the call just hangs forever and even alarm() cannot get you out.
@@ -214,8 +187,6 @@ Don't complain to me...
 
 EOF on the slave tty is not reported back to the master.
 
-=item * z/OS
-
 =back
 
 The following systems have not been verified yet for this version, but
@@ -263,8 +234,8 @@ E<lt>F<RGiersig@cpan.org>E<gt>.
 
 Contains copyrighted stuff from openssh v3.0p1, authored by Tatu
 Ylonen <ylo@cs.hut.fi>, Markus Friedl and Todd C. Miller
-<Todd.Miller@courtesan.com>.  I also got a lot of inspiration from
-the pty code in Xemacs.
+<Todd.Miller@courtesan.com>.  I also got a lot of inspiry from the pty
+code in Xemacs.
 
 
 =head1 COPYRIGHT
